@@ -166,12 +166,17 @@ class ResponseManager:
             # Handle the case where the response is not JSON
             self.current_response = {"error": "Response is not in JSON format", "data": self.response.text}
         # Save the response using SaveManager
-        self.query_js['response']=safe_json_loads(self.current_response)
+        self.current_response = safe_json_loads(self.current_response)
+        self.query_js['response']=self.current_response
         
+        slices = ['response','choices',0,'message','content']
+        for key in slices:
+            if isinstance(key,int):
+                if isinstance(self.current_response,list) and self.current_response:
+                    self.current_response=safe_json_loads(self.current_response[0])
+            elif key in self.current_response:
+                self.current_response=safe_json_loads(self.current_response[key])
         self.save_manager = SaveManager(data=self.query_js['response'], title=self.query_js['response'].get('created','response'), directory=['response_data','raw_response'], model=self.query_js['response'].get('model','default'))
-        self.current_content = safe_json_loads(get_any_value(self.query_js['response'],'content'))
-        if self.current_content and isinstance(self.current_content,list):
-            self.current_content=safe_json_loads(self.current_content[0])
         self.error = None
         self.error_response = get_any_value(self.query_js['response'],'error')
         if self.error_response:
@@ -187,7 +192,7 @@ class ResponseManager:
         """
         Attempts to load the response content into a structured format.
         """
-        self.api_response = safe_json_loads(self.get_response())
+        self.current_content = safe_json_loads(self.get_response())
     def extract_response(self)->dict:
         """
         Processes the response and manages the creation of a save point through `SaveManager`.
